# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-05-30 23:24
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('fec_dbsync', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='generalaccount',
            old_name='Acct_status',
            new_name='ACCT_STATUS',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='acid',
            new_name='ACID',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='charge_off_flag',
            new_name='CHRGE_OFF_FLG',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='cif_id',
            new_name='CIF_ID',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='current_balance',
            new_name='CURRENT_BAL',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='debt_group',
            new_name='DEBT_GROUP',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='disb_date',
            new_name='DISB_DATE',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='dpd_ason_date',
            new_name='DPD_ASON_DATE',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='dpd_cntr',
            new_name='DPD_CNTR',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='inst_start_date',
            new_name='INST_START_DATE',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='int_dmd_os',
            new_name='INT_DMD_OS',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='lms_schm_code',
            new_name='LMS_SCHM_CODE',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='loan_account_number',
            new_name='LOAN_ACCT_NUM',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='maturity_date',
            new_name='MATURITY_DATE',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='past_due_flag',
            new_name='PAST_DUE_FLG',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='payoff_date',
            new_name='PAYOFF_DATE',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='pms_schm_desc',
            new_name='PMS_SCHM_DESC',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='pms_schm_id',
            new_name='PMS_SCHM_ID',
        ),
        migrations.RenameField(
            model_name='generalaccount',
            old_name='prin_dmd_os',
            new_name='PRIN_DMD_OS',
        ),
    ]
