# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-06-08 08:58
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fec_dbsync', '0006_auto_20180607_2053'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='roboidtview',
            name='ACCRUED_DMD_AMT',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='BANK_ID',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='CRYSTALLISED_AMT',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='DEL_FLG',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='DEMAND_IND',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='DMD_DATE',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='DMD_FLOW_ID',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='EI_AMT',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='LATEFEE_STATUS_FLG',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='LCHG_TIME',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='LCHG_USER_ID',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='LDT_CRNCY_CODE',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='LD_FREQ_TYPE',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='RCRE_TIME',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='RCRE_USER_ID',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='SHDL_NUM',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='TOT_REFUND_AMT',
        ),
        migrations.RemoveField(
            model_name='roboidtview',
            name='TS_CNT',
        ),
        migrations.AddField(
            model_name='robochatview',
            name='CHAT_CREATION_TIME',
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name='robochatview',
            name='CHAT_LAST_CHANGE_TIME',
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name='robochatview',
            name='GAM_CREATION_TIME',
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name='robochatview',
            name='GAM_LAST_CHANGE_TIME',
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name='roboidtview',
            name='GAM_CREATION_TIME',
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name='roboidtview',
            name='GAM_LAST_CHANGE_TIME',
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name='roboidtview',
            name='LAST_WAIVER_ADJ_DATE',
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name='roboidtview',
            name='LDT_CREATION_TIME',
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name='roboidtview',
            name='LDT_LAST_CHANGE_TIME',
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name='roboidtview',
            name='WAIVED_AMT',
            field=models.BigIntegerField(null=True),
        ),
        migrations.AlterField(
            model_name='roboclelarshview',
            name='CHRG_CMP',
            field=models.IntegerField(null=True),
        ),
        migrations.AlterField(
            model_name='roboclelarshview',
            name='INT_CMP',
            field=models.IntegerField(null=True),
        ),
        migrations.AlterField(
            model_name='roboclelarshview',
            name='LCHG_TIME',
            field=models.DateField(null=True),
        ),
        migrations.AlterField(
            model_name='roboclelarshview',
            name='PRIN_CMP',
            field=models.IntegerField(null=True),
        ),
        migrations.AlterField(
            model_name='roboclelarshview',
            name='RCRE_TIME',
            field=models.DateField(null=True),
        ),
        migrations.AlterField(
            model_name='roboclelarshview',
            name='REP_SHDL_DATE',
            field=models.DateField(null=True),
        ),
        migrations.AlterField(
            model_name='roboclelarshview',
            name='TOTAL_FLOW',
            field=models.IntegerField(null=True),
        ),
        migrations.AlterField(
            model_name='roboidtview',
            name='DMD_AMT',
            field=models.BigIntegerField(null=True),
        ),
        migrations.AlterField(
            model_name='roboidtview',
            name='DMD_EFF_DATE',
            field=models.DateField(null=True),
        ),
        migrations.AlterField(
            model_name='roboidtview',
            name='DMD_OVDU_DATE',
            field=models.DateField(null=True),
        ),
        migrations.AlterField(
            model_name='roboidtview',
            name='LAST_ADJ_DATE',
            field=models.DateField(null=True),
        ),
        migrations.AlterField(
            model_name='roboidtview',
            name='TOT_ADJ_AMT',
            field=models.IntegerField(null=True),
        ),
        migrations.AlterField(
            model_name='roborepayuplview',
            name='FILE_NAME',
            field=models.TextField(null=True),
        ),
    ]
